class Kuzu < Formula
  desc "Embeddable graph database management system built for query speed & scalability"
  homepage "https://kuzudb.com/"
  url "https://github.com/kuzudb/kuzu/archive/refs/tags/v0.4.2.tar.gz"
  sha256 "47057d6b241b13a989b39d5277c234cdae19291f9cce7a642113bbe7ab916ad6"
  license "MIT"
  head "https://github.com/kuzudb/kuzu.git", branch: "master"

  depends_on "cmake" => :build
  depends_on "python@3.12" => :build

  def install
    args = %w[
      -DAUTO_UPDATE_GRAMMAR=0
    ]

    system "cmake", "-S", ".", "-B", "build", *args, *std_cmake_args
    system "cmake", "--build", "build"
    system "cmake", "--install", "build"
  end

  test do
    db_path = testpath/"testdb/"
    cypher_path = testpath/"test.cypher"
    cypher_path.write <<~EOS
      CREATE NODE TABLE Person(name STRING, age INT64, PRIMARY KEY(name));
      CREATE (:Person {name: 'Alice', age: 25});
      CREATE (:Person {name: 'Bob', age: 30});
      MATCH (a:Person) RETURN a.name AS NAME, a.age AS AGE ORDER BY a.name ASC;
    EOS

    output = shell_output("#{bin}/kuzu #{db_path} < #{cypher_path}")

    expected_1 = <<~EOS
      ----------------------------------
      | result                         |
      ----------------------------------
      | Table Person has been created. |
      ----------------------------------
    EOS
    expected_2 = <<~EOS
      ---------------
      | NAME  | AGE |
      ---------------
      | Alice | 25  |
      ---------------
      | Bob   | 30  |
      ---------------
    EOS

    assert_match expected_1, output
    assert_match expected_2, output
  end
end
